// Queue class

function Queue () {

	var self = this;

	this.reset = function () {
		this.busy = false;
		this.items = [];
		this.froms = [];
		this.oneByOne = false;
		this.delay = 0;
	}
	
	this.reset();

	this.add = function (delivery) {
		this.items.push(delivery);
		if (!this.oneByOne) {
			if (delivery.passRequired || delivery.oneByOne) {
				var checkValue = (delivery.passRequired) ? delivery.extra : delivery.no;
				if (this.froms[delivery.from]) {
					if (this.froms[delivery.from] != checkValue) this.oneByOne = true;
				} else this.froms[delivery.from] = checkValue;
			}
		}
	}

	this.update = function () {
		if (this.items.length) {
			this.busy = true;
			if (this.oneByOne || this.delay) {
				var delivery = this.items.shift();
				delivery.updateStatus();
				if (!this.oneByOne) setTimeout(function(){ self.update() },this.delay);
				if (!this.items.length) this.reset();
			} else {
				do {
					var delivery = this.items.shift();
					delivery.updateStatus();
				} while (this.items.length);
				this.reset();
			}
		} else if (!iPhone) {
			setTimeout(finishUpdate,500);
		}
	}

	this.updateIfIdle = function () {
		if (!this.busy) this.update();
	}

	this.count = function () {
		return this.items.length;
	}

}

// Delivery class

function Delivery (settings) {

	var self = this;
	this.req = [];

	// Functions
	this.setUpdatableFunctions = setUpdatableFunctions;
	this.setUpdatableFunctions();

	this.setDelivery = setDelivery;
	this.loadPage = loadPage;
	this.loadCookiePage = loadCookiePage;
	this.loadSection = loadSection;
	this.resetRequests = resetRequests;
	this.connectFailed = connectFailed;
	this.notFound = notFound;
	this.updateComplete = updateComplete;
	this.updateItems = updateItems;
	this.parseDate = parseDate;
	this.showMessage = showMessage;
	this.saveItems = saveItems;

	if (!iPhone) {
		this.loading = false;
		this.spinAngle = 0;
		this.startLoad = startLoad;
		this.stopLoad = stopLoad;
		this.addButtons = addButtons;
		this.editParent = editParent;
		this.closeParent = closeParent;
	}
	this.setDelivery(settings);

}

function setUpdatableFunctions () {
	this.updateStatus = updateStatus;
	this.startUpdate = startUpdate;
	this.cleanDate = cleanDate;
	this.cleanLocation = cleanLocation;
}

function setDelivery (settings) {

	this.reqCount = 0;
	this.reqComplete = 0;

	//  Success values:
	// -1: Couldn't connect, no internet
	//  0: Couldn't connect, site down
	//  1: Not found
	//  2: Found

	this.success = 2;
	this.lastUpdate = 0;
	this.nextUpdate = 0;
	this.interval = 0;
	this.items = [];
	this.previousItems = false;
	this.count = 0;

	this.fromEdited = false;
	this.skipExtra = false;
	this.icon = '';
	this.tries = 0;
	this.tap = false;

	// Initialization
	this.id = settings.uuid;
	this.name = (settings.name) ? settings.name : '';
	this.from = (settings.from) ? settings.from : 'www.amazon.com';
	this.extra = (settings.extra) ? settings.extra : '';
	this.no = (settings.no) ? settings.no : '';

	this.date = false;
	if (settings.date) this.date = stringToTimeStamp(settings.date);

	if (!iPhone) {
		if (this.extra) this.password = getPassword(this.from,this.extra);
	} else this.password = (settings.password) ? settings.password : 0;

	this.html = (settings.html) ? settings.html : '';
	this.htmldate = (settings.htmldate) ? settings.htmldate : '';
	this.displayed = (settings.displayed) ? settings.displayed : 0;

	setService(this,false,false);
	this.fromName = getFromName(this.from,false,false);
	this.fromTrans = getFromName(this.from,true,false);

}

function loadPage (url,method,postData,args) {

	var reqNo = this.reqCount;
	this.reqCount++;
	this.req[reqNo] = new XMLHttpRequest();
	if (!this.sync) this.req[reqNo].delivery = this;
	this.req[reqNo].args = args;
	this.req[reqNo].getTracker = getTracker;
	this.req[reqNo].onload = method;

	var request = this.req[reqNo];
	this.req[reqNo].onreadystatechange = function(){
		if (this.timer && this.readyState >= 3) clearTimeout(this.timer);
		if (this.readyState == 4) {
			if (this.status == 0 && !this.responseText) {
				if (!iPhone && !request.delivery) {
					syncFail(args);
				} else {
					this.abort(); // Stops onload from getting called in 10.5
					this.delivery.connectFailed();
				}
			}
		}
	}

	if (postData) {
		this.req[reqNo].open('POST',url);
		this.req[reqNo].setRequestHeader('Content-type','application/x-www-form-urlencoded');
		this.req[reqNo].setRequestHeader('Cache-Control','no-cache');
		this.req[reqNo].setRequestHeader('Content-length',postData.length);
		this.req[reqNo].setRequestHeader('Connection','close');
		this.req[reqNo].send(postData);
	} else {
		this.req[reqNo].open('GET',url);
		this.req[reqNo].setRequestHeader('Cache-Control','no-cache');
		this.req[reqNo].send();
	}

	if (iPhone) {
		this.req[reqNo].timer = setTimeout(function(){
			request.abort();
			request.delivery.connectFailed();
		},30000);
	} else if (this.sync) {
		var timeout = (sync.updated > 1) ? 15000 : 30000;
		this.req[reqNo].timer = setTimeout(function(){
			syncFail(args);
		},timeout);
	}

}

function setArgs (site,childNo) {
	var args = {};
	args.site = site;
	args.childNo = (childNo === false) ? 0 : childNo;
	args.isChild = (childNo === false) ? false : true;
	return args;
}

function DummyRequest (delivery,responseText,args) {
	this.delivery = delivery;
	this.responseText = responseText;
	this.status = 200;
	this.args = args;
	this.abort = function(){};
	this.getTracker = getTracker;
	this.getTracker();
}

function loadSection (section,args) {
	var reqNo = this.reqCount;
	this.reqCount++;
	this.req[reqNo] = new DummyRequest(this,section,args);
}

function resetRequests (cancelAll) {
	if (cancelAll) {
		for (i in this.req) {
			if (this.req[i]) {
				this.req[i].abort();
				clearTimeout(this.req[i].timer);
			}
		}
	}
	this.reqCount = 0;
	this.reqComplete = 0;
}

function connectFailed () {
	if (!this.count) this.count = -1;
	this.notFound(false,true);
	this.reqComplete++;
	this.updateItems();
}

function notFound (title,connectionDown) {

	if (!iPhone) this.stopLoad();
	if (this.count == 0) {
	
		this.count = -1;
		this.items = [];
		this.items[0] = resetItem();

		this.items[0].icon = 'error';
		this.items[0].title = (this.name)?htmlEntities(this.name):htmlEntities(this.no);
		this.items[0].shipText  = title ? (title) : translate('Not found');
		this.items[0].deliverText = translate('Please check your settings.');
		this.items[0].shipBold = this.items[0].shipExtraBold = true;
		this.items[0].deliverBold = this.items[0].deliverExtraBold = false;

		if (this.passRequired && (!this.password || this.password == ' ')) {
			this.items[0].shipText = translate('Password required');
			if (iPhone) {
				this.tap = 'password';
				this.items[0].deliverText = translate('Tap to enter your password.');
			} else {
				this.items[0].deliverText = '<a href="javascript:editPassword(\''+this.id+'\');">'+
					translate('Click to enter your password.')+'</a>';
				this.items[0].deliverBold = this.items[0].deliverExtraBold = true;
				this.items[0].clickable = true;
			}
		} else if (!iPhone && DeliveryStatus && !DeliveryStatus.cookiesEnabled()) {
			this.items[0].shipText = translate('Cookies are required');
			this.items[0].deliverText = '<a href="javascript:openSite(\'http://junecloud.com/support/delivery-status-cookies.html\');">'+
				translate('Click here for help.')+'</a>';
			this.items[0].deliverBold = this.items[0].deliverExtraBold = true;
			this.items[0].clickable = true;
		}

		this.items[0].shipExtra = this.items[0].shipText;
		this.items[0].deliverExtra = this.items[0].deliverText;
		this.success = 1;
		this.displayed = 0;

	} else if (this.count == -1) {

		this.items = [];
		this.items[0] = resetItem();

		this.items[0].icon = 'error';
		this.items[0].title = (this.name)?htmlEntities(this.name):htmlEntities(this.no);
		this.items[0].shipText = translate('Couldn’t connect');
		this.items[0].deliverText = this.fromTrans+' '+translate('is not available.'); 
		this.items[0].shipExtra = this.items[0].shipText;
		this.items[0].shipBold = this.items[0].shipExtraBold = true;
		this.items[0].deliverExtra = this.items[0].deliverText;
		this.items[0].deliverBold = this.items[0].deliverExtraBold = false;
		this.success = (connectionDown) ? -1 : 0;
		this.displayed = 0;

	} else this.success = (connectionDown) ? -1 : 0;

	if (!iPhone) checkVersion(1,true);

}

// End of Delivery class

function getOther () {

	var delivery = this.delivery;
	if (!iPhone) delivery.oldhtml = delivery.html;

	if ((this.status == 200 || this.status == 0) && this.responseText) {
		delivery.html = stripWhiteSpace(this.responseText);
	} else {
		if (!delivery.count) delivery.count = -1;
		delivery.notFound();
	}

	if (!iPhone) updateOther(delivery);

	delivery.reqComplete++;
	delivery.updateItems();
	return;

}

function updateComplete () {
	return (this.reqComplete >= this.reqCount) ? true : false;
}

function updateItems () {

	if (this.updateComplete()) {

		this.previousItems = false;

		var newInterval = 1440;
		if (this.success == -1) { // Couldn't connect, no internet
			newInterval = 0;
		} else if (this.success <= 1) { // Not found or couldn't connect, site down
			newInterval = 60;
		}

		if (this.from == 'other') {

			if (newInterval > 60) newInterval = 60;
			if (this.success > 0) this.lastUpdate = new Date();

		} else if (this.count > 0) {

			for (var x in this.items) {
				var item = this.items[x];
				var result = false;
				var hasDeliveryDays = false;
	
				item.details.date = stripHTML(item.details.date);
				item.details.location = stripHTML(item.details.location);
				item.details.status = stripHTML(item.details.status);

				// Update the display
				if (item.shipSaved || !item.shipText) {
					result = this.parseDate(item.shipSaved,item.status,item.details,'Shipped');
					item.shipText = result[0];
					item.shipExtra = result[1];
					item.daysNo = result[2];
					item.shipDate = result[3];
					item.shipBold = result[4];
					item.shipExtraBold = result[5];
					item.statusDate = (result[6]) ? result[6] : result[3];					
					item.date = result[3];
				}
				if (item.deliverSaved || !item.deliverText) {
					result = this.parseDate(item.deliverSaved,item.status,false,'Delivered');
					item.deliverText = result[0];
					item.deliverExtra = result[1];
					item.deliverDate = result[3];
					item.deliverBold = result[4];
					item.deliverExtraBold = result[5];
					if (result[2] !== false && result[2] >= 0) {
						item.daysNo = result[2];
						hasDeliveryDays = true;
					}
					if (result[3]) item.date = result[3];
				}

				if (item.status.match(/^complete$/i)) {
					item.icon = 'checkmark';
				} else if (item.daysNo > 999) {
					item.icon = '';	
				} else if (item.daysNo > 99) {
					item.icon = '';	
				} else if (item.daysNo > 0 || (item.daysNo === 0 && trim(item.deliverSaved))) {
					item.icon = '';
				} else if (!item.icon) {
					item.icon = 'transit';
				}

				var interval = getInterval(item.icon,item.daysNo,hasDeliveryDays);
				if (interval < newInterval) newInterval = interval;

				this.items[x] = item;
			}
			if (this.success > 0) this.lastUpdate = new Date();

		}

		this.resetRequests(false);
		this.interval = newInterval;

		if (iPhone) {
			this.saveItems(this.displayed,this.items);
		} else {
			this.nextUpdate = ((new Date()).getTime()/1000)+(this.interval * 60);
			if (this.success > 0) {
				hadSuccess = true;
				if (this.success == 2) setHistoryTitle(this.id);
			}
			displayItem(this.id,this.displayed,false);
			showNotifications(this);
			this.saveItems();
		}
		updateQueue.update();

	}

}

function getInterval (icon,daysApart,hasDeliveryDays) {
	var interval = 60;
	if (icon == 'checkmark') {
		interval = 1440;
	} else if (hasDeliveryDays && daysApart <= -3) {
		interval = 300;
	} else if (daysApart <= 3) {
		interval = 20;
	} else if (daysApart <= 10) {
		interval = 60;
	} else if (daysApart > 10) {
		interval = 300;
	}
	return interval;
}

function resetItem () {

	var item = {};
	item.title = translate('Unknown Item');
	item.status = '';
	item.statusDate = 0;
	item.date = '';
	item.icon = '';
	item.daysNo = false;

	item.details = {};
	item.details.date = '';
	item.details.location = '';
	item.details.status = '';

	item.shipSaved = '';
	item.shipText = ''; 
	item.shipBold = false;
	item.shipExtra = '';
	item.shipExtraBold = false;
	item.shipDate = 0;

	item.deliverSaved = '';
	item.deliverText = '';
	item.deliverBold = false;
	item.deliverExtra = '';
	item.deliverExtraBold = false;
	item.deliverDate = 0;
	item.clickable = false;

	return item;

}

// Helper functions

function translate (key) {
	try {
		var ret = translation[key];
		if (ret === undefined) ret = key;
		return ret;
	} catch (ex) { }
	return key;
}

function translateFormat (key,value1,value2,value3) {
	key = translate(key);
	if (value1) key = key.replace('%@',value1);
	if (value2) key = key.replace('%@',value2);
	if (value3) key = key.replace('%@',value3);
	return key;
}

function getUnixTime () {
	var currentTime = new Date();
	return currentTime.getTime()/1000;
}

// Display text

function stripWhiteSpace (string) {
	return (typeof string == 'string') ? string.replace(/(\s|\n)+/g,' ') : '';
}

function trim (string) {
	if (typeof string == 'string') {
		// Remove non-breaking space characters (&#160; or \xAO)
		while (string.indexOf(' ') > -1) {
			string = string.replace(' ',' ');
		}
		string = string.replace(/^(\s|&nbsp;)+|(\s|&nbsp;)+$/ig,'');
	}
	return string;
}

function clearEmptyString (string) {
	return (typeof string == 'string') ? string.replace(/^ ?-+ ?$/,'') : '';
}

function stripHTML (string) {
	if (typeof string == 'string') {

		// Deal with some really ugly HTML from UPS Mail Innovations
		string = string.replace(/<a [^>]*onmouseover="([^"]*)"[^>]*>/g,' ');

		// Remove script, noscript, and style tags
		string = string.replace(/<(noscript|script|style) ?[^>]*>(.*?)<\/\1>/ig,' ');

		// Remove HTML tags
		string = string.replace(/<[^>]*>/g,' ');

		// Remove non-breaking space characters (&#160; or \xAO) and reduce mutiple spaces
		while (string.indexOf(' ') > -1) string = string.replace(' ',' ');
		string = string.replace(/(&nbsp;|\s)+/g,' ');

		// Convert some HTML entities
		string = string.replace(/&quot;/g,'"');

	}
	return trim(string);
}

function htmlEntities (string) {
	if (typeof string == 'string') {
		string = string.replace(/\&/g,'&#38;');
		string = string.replace(/"/g,'&quot;');
		string = string.replace(/</g,'&#60;');
		string = string.replace(/>/g,'&#62;');
	}
	return string;
}

function decodeDecimalEntities (string) {
	return string.replace(/&#(\d+);/g, 
		function (whole,parens) {
			if (parens >= -32768 && parens <= 65535) {
				return String.fromCharCode(parens);
			} else return whole;
		});
}

function removeHtmlEntities (string) {
	if (typeof string == 'string') {
		string = decodeDecimalEntities(string);

		string = string.replace(/\&amp;/g,'&');
		string = string.replace(/&quot;/g,'"');
		string = string.replace(/&nbsp;/g,' ');
		string = string.replace(/&ndash;/g,'–');
		string = string.replace(/&mdash;/g,'—');

		string = string.replace(/\&auml;/g,'ä');
		string = string.replace(/\&euml;/g,'ë');
		string = string.replace(/\&iuml;/g,'ï');
		string = string.replace(/\&ouml;/g,'ö');
		string = string.replace(/\&uuml;/g,'ü');
		string = string.replace(/\&Auml;/g,'Ä');
		string = string.replace(/\&Euml;/g,'Ë');
		string = string.replace(/\&Iuml;/g,'Ï');
		string = string.replace(/\&Ouml;/g,'Ö');
		string = string.replace(/\&Uuml;/g,'Ü');

		string = string.replace(/\&aacute;/g,'á');
		string = string.replace(/\&eacute;/g,'é');
		string = string.replace(/\&iacute;/g,'í');
		string = string.replace(/\&oacute;/g,'ó');
		string = string.replace(/\&uacute;/g,'ú');
		string = string.replace(/\&Aacute;/g,'Á');
		string = string.replace(/\&Eacute;/g,'É');
		string = string.replace(/\&Iacute;/g,'Í');
		string = string.replace(/\&Oacute;/g,'Ó');
		string = string.replace(/\&Uacute;/g,'Ú');

		string = string.replace(/\&agrave;/g,'à');
		string = string.replace(/\&egrave;/g,'è');
		string = string.replace(/\&igrave;/g,'ì');
		string = string.replace(/\&ograve;/g,'ò');
		string = string.replace(/\&ugrave;/g,'ù');
		string = string.replace(/\&Agrave;/g,'À');
		string = string.replace(/\&Egrave;/g,'È');
		string = string.replace(/\&Igrave;/g,'Ì');
		string = string.replace(/\&Ograve;/g,'Ò');
		string = string.replace(/\&Ugrave;/g,'Ù');

		string = string.replace(/\&acirc;/g,'â');
		string = string.replace(/\&ecirc;/g,'ê');
		string = string.replace(/\&icirc;/g,'î');
		string = string.replace(/\&ocirc;/g,'ô');
		string = string.replace(/\&ucirc;/g,'û');
		string = string.replace(/\&Acirc;/g,'Â');
		string = string.replace(/\&Ecirc;/g,'Ê');
		string = string.replace(/\&Icirc;/g,'Î');
		string = string.replace(/\&Ocirc;/g,'Ô');
		string = string.replace(/\&Ucirc;/g,'Û');

		string = string.replace(/\&agrave;/g,'à');
		string = string.replace(/\&egrave;/g,'è');
		string = string.replace(/\&igrave;/g,'ì');
		string = string.replace(/\&ograve;/g,'ò');
		string = string.replace(/\&ugrave;/g,'ù');
		string = string.replace(/\&Agrave;/g,'À');
		string = string.replace(/\&Egrave;/g,'È');
		string = string.replace(/\&Igrave;/g,'Ì');
		string = string.replace(/\&Ograve;/g,'Ò');
		string = string.replace(/\&Ugrave;/g,'Ù');

		string = string.replace(/\&ntilde;/g,'ñ');
		string = string.replace(/\&atilde;/g,'ã');
		string = string.replace(/\&otilde;/g,'õ');
		string = string.replace(/\&Ntilde;/g,'Ñ');
		string = string.replace(/\&Atilde;/g,'Ã');
		string = string.replace(/\&Otilde;/g,'Õ');

		string = string.replace(/\&aring;/g,'å');
		string = string.replace(/\&Aring;/g,'Å');

		string = string.replace(/\&oslash;/g,'ø');
		string = string.replace(/\&Oslash;/g,'Ø');
		
		string = string.replace(/\&copy;/g,'©');
	}
	return string;
}

function cleanOtherHTML (string) {
	if (typeof string == 'string') {
		string = string.replace(/<[^>]*FOOTER START[^>]*>(.*?)<[^>]*FOOTER END[^>]*>/i,' '); // interparcel.com
		string = string.replace(/<font class="secretTextNextGen"[^>]*>[^<]*<\/font>/i,' '); // dell.com
		string = stripWhiteSpace(stripHTML(string));
	}
	return string;
}

function doublePlusEncode (string) {
	return encodeURIComponent(string).replace(/%2B/g,'%252B');
}

// Parse dates

function stringToTimeStamp (string) {
	string = string.toString().replace(/-/g,'/');
	return new Date(string);
}

function parseDate (input,status,details,type) {

	var output = [];
	var end = false;

	output[0] = ''; // xText
	output[1] = ''; // xExtra
	output[2] = false; // daysNo
	output[3] = 0; // xDate
	output[4] = false; // xBold
	output[5] = false; // xExtraBold
	output[6] = 0; // statusDate

	if (type == 'Shipped') {
		output[0] = translate('Ship date unknown');
		output[1] = translate('Ship date unknown');
	} else {
		output[0] = translate('Delivery date unknown');
		output[1] = translate('Delivery date unknown');
	}

	input = this.cleanDate(input);
	end = input[1];
	input = input[0];

	if (status.match(/^complete$/i)) {

		output[0] = translate(type+'!');
		if (end) {
			output[1] = translate(type+' %@');
			output[3] = convertDate(end);
		} else {
			output[1] = translate(type+'!');
		}
		output[2] = 0;
		output[4] = true;
		output[5] = true;

	} else if (input) {

		if (end) {

			if (type == 'Shipped' && status.match(/^shipped$/i)) {
				output[0] = translate(type+'!');
				output[1] = translate(type+' %@');
				output[4] = true;
			} else {
				output[0] = output[1] = translate(type+' by %@');
				output[4] = false;
			}

			output[2] = getDaysApart(end);
			output[3] = convertDate(end);
			output[5] = false;

		} else {
			output[0] = output[1] = input;
			output[4] = true;
		}

	} else if (status.match(/^shipped$/i) && type == 'Shipped') {

		output[0] = output[1] = translate('Shipped!');
		output[4] = output[5] = true;

	}

	if (type == 'Shipped') {
		if (details.status) {
			if (!details.status.match(/^delivered$/i) || details.location) {

				output[0] = details.status;
				if (details.location && output[0].indexOf(details.location) == -1) output[0] += ': '+details.location;

				var detailDate = this.cleanDate(details.date);
				detailDate = detailDate[1];
				if (detailDate) output[1] = translate('Status updated %@');
				output[4] = true;
				output[6] = convertDate(detailDate);

			}
		} else if (status && !status.match(/^complete$/i) && !status.match(/^shipped$/i)) {
			output[0] = status;
			output[4] = true;
		}
	}

	return output;

}

function splitDate (string) {
	string = trim(string);
	result = string.match(/(.{2,}) - ([^(]*)/i);
	if (result && result[2]) string = result[2];
	return string;
}

function cleanGermanDate (string) {
	string = string.replace('.',' ');
	string = string.replace(/\bJanuar\s/i,'January ');
	string = string.replace(/\bFebruar\s/i,'February ');
	string = string.replace(/\bMärz\s/i,'March ');
	string = string.replace(/\bMai\s/i,'May ');
	string = string.replace(/\bJuni\s/i,'June ');
	string = string.replace(/\bJuli\s/i,'July ');
	string = string.replace(/\bOktober\s/i,'October ');
	string = string.replace(/\bDezember\s/i,'December ');
	return string;
}

function cleanSpanishDate (string) {
	string = string.replace(/\b(enero)\s/i,'January ');
	string = string.replace(/\b(feb)\.?\s/i,'February ');
	string = string.replace(/\b(marzo)\s/i,'March ');
	string = string.replace(/\b(abr)\.?\s/i,'April ');
	string = string.replace(/\b(mayo)\s/i,'May ');
	string = string.replace(/\b(jun)\.?\s/i,'June ');
	string = string.replace(/\b(jul)\.?\s/i,'July ');
	string = string.replace(/\b(agosto)\s/i,'August ');
	string = string.replace(/\b(sept|set)\.?\s/i,'September ');
	string = string.replace(/\b(oct)\.?\s/i,'October ');
	string = string.replace(/\b(nov)\.?\s/i,'November ');
	string = string.replace(/\b(dic)\.?\s/i,'December ');
	return string;
}

function cleanFrenchDate (string) {
	string = string.replace('.',' ');
	string = string.replace(/\bjanvier\s/i,'January ');
	string = string.replace(/\bfévrier\s/i,'February ');
	string = string.replace(/\bmars\s/i,'March ');
	string = string.replace(/\bavril\s/i,'April ');
	string = string.replace(/\bmai\s/i,'May ');
	string = string.replace(/\bjuin\s/i,'June ');
	string = string.replace(/\bjuillet\s/i,'July ');
	string = string.replace(/\baoût\s/i,'August ');
	string = string.replace(/\bseptembre\s/i,'September ');
	string = string.replace(/\boctobre\s/i,'October ');
	string = string.replace(/\bnovembre\s/i,'November ');
	string = string.replace(/\bdécembre\s/i,'December ');
	return string;
}

function cleanItalianDate (string) {
	string = string.replace(/\b(gen|genn)\.?\s/i,'January ');
	string = string.replace(/\b(feb|febbr)\.?\s/i,'February ');
	string = string.replace(/\b(mar)\.?\s/i,'March ');
	string = string.replace(/\b(apr)\.?\s/i,'April ');
	string = string.replace(/\b(mag|magg)\.?\s/i,'May ');
	string = string.replace(/\b(giu|giugno)\.?\s/i,'June ');
	string = string.replace(/\b(lug|luglio)\.?\s/i,'July ');
	string = string.replace(/\b(ago|ag)\.?\s/i,'August ');
	string = string.replace(/\b(set|sett)\.?\s/i,'September ');
	string = string.replace(/\b(ott)\.?\s/i,'October ');
	string = string.replace(/\b(nov)\.?\s/i,'November ');
	string = string.replace(/\b(dic)\.?\s/i,'December ');
	return string;
}

function cleanDanishDate (string) {
	string = string.replace('.',' ');
	string = string.replace(/\bjanuar\s/i,'January ');
	string = string.replace(/\bfebruar\s/i,'February ');
	string = string.replace(/\bmarts\s/i,'March ');
	string = string.replace(/\bmaj\s/i,'May ');
	string = string.replace(/\bjuni\s/i,'June ');
	string = string.replace(/\bjuli\s/i,'July ');
	string = string.replace(/\boktober\s/i,'October ');
	return string;
}

function getSwedishMonth (string) {
	switch (string) {
		case 'januari':		case 'jan':	return '1';
		case 'februari':	case 'feb':	return '2';
		case 'mars':		case 'mar':	return '3';
		case 'april':		case 'apr':	return '4';
		case 'maj':						return '5';
		case 'juni':		case 'jun':	return '6';
		case 'juli':		case 'jul':	return '7';
		case 'augusti':		case 'aug':	return '8';
		case 'september':	case 'sep':	return '9';
		case 'oktober':		case 'okt':	return '10';
		case 'november':	case 'mov':	return '11';
		case 'december':	case 'dec':	return '12';
	}
}

function getDaysApart (fromDate) {
	var date = new Date();
	date.setTime(fromDate);
	date.setHours(0);
	date.setMinutes(0);
	date.setSeconds(0);
	return Math.ceil((date-new Date())/86400000);
}

function getData (url) {
	var index = url.indexOf('?');
	if (index != -1) url = url.substring(index+1);
	url = url.replace(/\&amp;/g,'&');
	var parts = url.split('&');	
	var data = [];
	for (x in parts) {
		var part = parts[x].split('=');
		if (part[1]) data[decodeURIComponent(part[0])] = decodeURIComponent(part[1]);
	}
	return data;
}