var size = { width: 275, height: 140 };
var min  = { width: 104, height: 140 };
var max  = { width: 600, height: 140 };
var deliveriesMax = 140;
var offset = { x: 0, y: 0 };
var maximized = false;

var snapDist = 40;
var scrollArea;
var scrollWidth = 18;

function savedSize () {
	var width = 275;
	var height = 140;
	if (window.widget) {
		if (widget.preferenceForKey('width')) width = widget.preferenceForKey('width');
		if (widget.preferenceForKey('height')) height = widget.preferenceForKey('height');
	}
	return { width:width, height:height };
}

function maxForDeliveries (height) {
	return height + 15 + 51;
}

function setMinMax (view) {
	deliveriesMax = height = maxForDeliveries(deliveries.length * 74);
	switch (view) {

		case 'deliveries':
			min.width  = 104;
			min.height  = 140;
			if (height < min.height) {
				height = min.height;
			} else if (height > screen.height) {
				height = screen.height;
			}
			max.height = height;
			break;

		case 'edit':
			min.width  = 275;
			min.height = 390;
			max.height = (height > min.height) ? height : min.height;
			break;

		case 'general':
		case 'sync signin':
		case 'sync register':
		case 'donate':
			min.width  = 275;
			min.height = (view == 'sync register') ? 430 : 335;
			max.height = (height > min.height) ? height : min.height;
			break;

	}
}

function startResize (e) {
	offset.x = window.innerWidth - e.pageX;
	offset.y = window.innerHeight - e.pageY;
	document.addEventListener('mousemove', doResize, true);
	document.addEventListener('mouseup', stopResize, true);
}

function stopResize () {
	document.removeEventListener('mousemove', doResize, true);
	document.removeEventListener('mouseup', stopResize, true); 
	saveSize(size);
}

function doResize (e) {
	var scrollbars = (currentSide == 'front') ? true : false;
	setSize(e.pageX+offset.x,e.pageY+offset.y,scrollbars,false);
	if (scrollbars) showScrollBar();
}

function setSize (width,height,scrollbars,animating) {
	var className = (largePrint) ? 'large' : '';
	if (!animating) {
		if (height < min.height + snapDist) {
			height = min.height;
		} else if (height > max.height) {
			height = max.height;
		}
		var thisMin = (scrollbars && height < max.height) ? min.width + scrollWidth : min.width;
		if (width < thisMin + snapDist) {
			width = thisMin;
		} else if (width > max.width) {
			width = max.width;
		}
		if (height < deliveriesMax) className += ' scrolling';
		if (width < min.width + snapDist) className += ' mini';
	} else {
		className += ' animating';
	}
	$('front').className = className;
	
	window.resizeTo(width,height);
	size.width = width;
	size.height = height;
	if (!animating && scrollArea) scrollArea.refresh();
}

function setMaximized (size) {
	maximized = (currentSide == 'front' && size.height >= max.height) ? true : false;
}

function saveSize (size) {
	if (window.widget) {
		widget.setPreferenceForKey(size.width,'width');
		widget.setPreferenceForKey(size.height,'height');
	}
	setMaximized(size);
}

function rectHandler (rectAnimation,currentRect,startingRect,finishingRect) {
	setSize(currentRect.right,currentRect.bottom,true,true);
}


// changing views


function switchToView (side,view) {

	nextSide = side;
	nextView = view;
	setMinMax(nextView);

	if (currentSide == 'front') {
		scrollArea.blur();
		adjustSize();
	} else flipView();

}

function adjustSize (forceExpand) {

	var newSize = { width: size.width, height: size.height };
	if (currentSide != 'front') newSize = savedSize();

	if (min.width > newSize.width) {
		newSize.width = min.width;
	} else if (max.width < newSize.width) {
		newSize.width = max.width;
	}
	if (min.height > newSize.height) {
		newSize.height = min.height;
	} else if (max.height < newSize.height || forceExpand) {
		newSize.height = max.height;
	}
	if (forceExpand) saveSize(newSize);

	if (newSize.width != size.width || newSize.height != size.height) {
		var startingRect = new AppleRect(0,0,size.width,size.height);
		var finishingRect = new AppleRect(0,0,newSize.width,newSize.height);	
		var animation = new AppleRectAnimation(startingRect,finishingRect,rectHandler);
		var animator = new AppleAnimator(300,13);
		animator.addAnimation(animation);
		if (currentSide == 'front' && nextSide != 'front') {
			animator.oncomplete = flipView;
		} else animator.oncomplete = completeSwitch;
		animator.start();
	} else if (currentSide == 'front') {
		flipView();
	} else completeSwitch();

}

function flipView () {

	if (currentSide != nextSide) {
		var transition = (nextSide == 'front') ? 'ToFront' : 'ToBack';
		if (window.widget) widget.prepareForTransition(transition);
	}

	$(currentSide).style.display = 'none';
	if (nextSide == 'back') $('back').className = nextView;
	$(nextSide).style.display = 'block';

	setTimeout(function(){
			if (window.widget) widget.performTransition()
			if (currentSide == 'front' && nextSide != 'front') {
				completeSwitch();
			} else setTimeout(adjustSize,750);	
		},0);

}

function completeSwitch () {

	if (nextSide == 'front') {
		setSize(size.width,size.height,true,false);
		scrollArea.focus();
		animateQueues();
		showScrollBar();
	} else $('back').className = nextView;

	currentSide = nextSide;
	currentView = nextView;

	if (!currentSide) {
		currentSide = 'front';
		currentView = 'deliveries';
	} else if (currentSide == 'back' && currentView == 'edit' && !$('no').value) {
		$('name').focus();
	}

}

function selectTab (tab) {
	if (currentView == 'general') saveSettings(false);
	if (tab == 'general') checkNotifications();
	setMinMax(tab);
	if (size.height < min.height) {
		nextSide = 'back';
		nextView = tab;
		adjustSize();
	} else {
		$('back').className = tab;
		currentSide = 'back';
		currentView = tab;
	}
}